@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.27";
+our $VERSION = "1.2801";
 
 use v5.14;
 use warnings;
@@ -282,6 +282,7 @@ sub nup_out {
     my $reset = do { my @o = %$obj; sub { %$obj = @o } };
     for my $file (@files) {
 	my $data = $file->{data};
+	next if @$data == 0;
 	$obj->set_contents($data)
 	    ->set_vertical($data)
 	    ->set_layout($data)
@@ -299,7 +300,7 @@ sub read_files {
 	my $content = do { local $/; <$fh> };
 	my @data = $obj->pages ? split(/\f/, $content) : $content;
 	for my $data (@data) {
-	    my @line = split /\R/, $data;
+	    my @line = split /\n/, $data;
 	    @line = insert_space @line if $obj->paragraph;
 	    my @length;
 	    my $length = do {
@@ -312,7 +313,7 @@ sub read_files {
 	    };
 	    push @files, {
 		name   => $file,
-		length => $length,
+		length => $length // 0,
 		data   => \@line,
 	    };
 	}
